@@ -1,9 +1,7 @@
 # -*- coding: UTF-8 -*-
 
-from ast import literal_eval
 from os import makedirs
-from os.path import dirname, realpath, exists, isdir
-from typing import Any
+from os.path import dirname, realpath, exists
 
 
 def ensure_folder(path: str):
@@ -19,13 +17,25 @@ def ensure_folder(path: str):
 
 def make_dirs(path: str):
     """Checks if a folder path exists and create one if not."""
-    if (not exists(path)) and (not isdir(path)):
+    if not exists(path):
         makedirs(path)
 
 
-def evaluate(value: str) -> Any:
-    """Transform a string to an appropriate data type."""
-    try:
-        return literal_eval(value)
-    except (SyntaxError, ValueError):
-        raise
+def folder(value: str) -> str:
+    """
+    Return `value` as path and recursively
+    create the folder structure if needed.
+    """
+    value: str = realpath(value)
+    make_dirs(value)
+    return value
+
+
+def file(value: str) -> str:
+    """
+    Return `value` as path and recursively
+    create the folder structure if needed.
+    """
+    value: str = realpath(value)
+    ensure_folder(value)
+    return value
